==> portal-transparencia-2.011.1.zip: BOOT-INF/classes/db/sql/contab/convenio-pagamentos.sql <==
SELECT DATA, SUM(VALOR) VALOR FROM (                        
SELECT OP.DATA AS DATA, SUM(OPL.VALOR) AS VALOR             
  FROM ORDEMPAGAMENTO_LIQUIDACAO OPL                        
  LEFT OUTER JOIN PAGAMENTO OP                              
    ON OPL.ENTIDADE  = OP.ENTIDADE                          
   AND OPL.EXERCICIO = OP.ANOORDEMPAGAMENTO                 
   AND OPL.NOORDEM   = OP.NOORDEMPAGAMENTO                  
  LEFT OUTER JOIN EXERCICIO B                               
    ON OP.ENTIDADE  = B.ENTIDADE                            
   AND OP.EXERCICIO = B.EXERCICIO                           
  LEFT OUTER JOIN CONTABILCONTABANCO CCB                    
    ON OP.ENTIDADE    = CCB.ENTIDADE                        
   AND OP.EXERCICIO   = CCB.EXERCICIO                       
   AND OP.CONTADEBITO = CCB.CONTACONTABIL                   
  LEFT OUTER JOIN EMPENHO E                                 
    ON OPL.ENTIDADE         = E.ENTIDADE                    
   AND OPL.ANODOCORIGEM     = E.EXERCICIO                   
   AND OPL.NODOCORIGEM      = E.EMPENHO                     
   AND OPL.UNIDADEDOCORIGEM = E.UNIDADEORCAMENTARIA         
 WHERE E.ENTIDADE         = :entidade                       
   AND ((E.CONTRAPARTIDA  = 'N')                          
    OR  (E.CONTRAPARTIDA  IS NULL))                         
   AND OP.ESTORNO         = 'N'                           
   AND ((OP.IDCONTACORRENTE = :idContaCorrente              
   AND   B.MODELOPLANO      >= 8)                           
    OR  (CCB.REDUZIDO       = :local                        
   AND   NOT B.MODELOPLANO  < 8))                           
 GROUP BY OP.DATA                                           
 UNION ALL                                                  
SELECT RL.DATACONTABILIZADO AS DATA, SUM(RL.VALOR) AS VALOR 
  FROM ORDEMPAGAMENTO_LIQUIDACAO OPL                        
  LEFT OUTER JOIN PAGAMENTO OP                              
    ON OPL.ENTIDADE  = OP.ENTIDADE                          
   AND OPL.EXERCICIO = OP.ANOORDEMPAGAMENTO                 
   AND OPL.NOORDEM   = OP.NOORDEMPAGAMENTO                  
  LEFT OUTER JOIN EXERCICIO B                               
    ON OP.ENTIDADE  = B.ENTIDADE                            
   AND OP.EXERCICIO = B.EXERCICIO                           
  LEFT OUTER JOIN CONTABILCONTABANCO CCB                    
    ON OP.ENTIDADE    = CCB.ENTIDADE                        
   AND OP.EXERCICIO   = CCB.EXERCICIO                       
   AND OP.CONTADEBITO = CCB.CONTACONTABIL                   
  LEFT OUTER JOIN EMPENHO E                                 
    ON OPL.ENTIDADE         = E.ENTIDADE                    
   AND OPL.ANODOCORIGEM     = E.EXERCICIO                   
   AND OPL.NODOCORIGEM      = E.EMPENHO                     
   AND OPL.UNIDADEDOCORIGEM = E.UNIDADEORCAMENTARIA         
  JOIN RETENCOESLIQUIDACAO RL                               
    ON RL.ENTIDADE         = OPL.ENTIDADE                   
   AND RL.EXERCICIO        = OPL.EXERCICIOLIQ               
   AND RL.TIPODOCORIGEM    = OPL.TIPODOCORIGEM              
   AND RL.ANODOCORIGEM     = OPL.ANODOCORIGEM               
   AND RL.NODOCORIGEM      = OPL.NODOCORIGEM                
   AND RL.UNIDADEDOCORIGEM = OPL.UNIDADEDOCORIGEM           
   AND RL.NOLIQUIDACAO     = OPL.NOLIQUIDACAO               
 WHERE E.ENTIDADE         = :entidade                       
   AND ((E.CONTRAPARTIDA  = 'N')                          
    OR  (E.CONTRAPARTIDA  IS NULL))                         
   AND OP.ESTORNO         = 'N'                           
   AND ((OP.IDCONTACORRENTE = :idContaCorrente              
   AND   B.MODELOPLANO      >= 8)                           
    OR  (CCB.REDUZIDO       = :local                        
   AND   NOT B.MODELOPLANO  < 8))                           
 GROUP BY RL.DATACONTABILIZADO                              
 ) PAGAMENTOS                                               
 GROUP BY DATA                                              
 ORDER BY DATA

==> portal-transparencia-2.113.0.zip: BOOT-INF/classes/db/sql/contab/convenio-pagamentos.sql <==
SELECT DATA, SUM(VALOR) VALOR FROM (                        
SELECT OP.DATA AS DATA, SUM(OPL.VALOR) AS VALOR             
  FROM ${db.contabilidade.schema}.ORDEMPAGAMENTO_LIQUIDACAO OPL
  LEFT OUTER JOIN ${db.contabilidade.schema}.PAGAMENTO OP
    ON OPL.ENTIDADE  = OP.ENTIDADE                          
   AND OPL.EXERCICIO = OP.ANOORDEMPAGAMENTO                 
   AND OPL.NOORDEM   = OP.NOORDEMPAGAMENTO                  
  LEFT OUTER JOIN ${db.contabilidade.schema}.EXERCICIO B
    ON OP.ENTIDADE  = B.ENTIDADE                            
   AND OP.EXERCICIO = B.EXERCICIO                           
  LEFT OUTER JOIN ${db.contabilidade.schema}.CONTABILCONTABANCO CCB
    ON OP.ENTIDADE    = CCB.ENTIDADE                        
   AND OP.EXERCICIO   = CCB.EXERCICIO                       
   AND OP.CONTADEBITO = CCB.CONTACONTABIL                   
  LEFT OUTER JOIN ${db.contabilidade.schema}.EMPENHO E
    ON OPL.ENTIDADE         = E.ENTIDADE                    
   AND OPL.ANODOCORIGEM     = E.EXERCICIO                   
   AND OPL.NODOCORIGEM      = E.EMPENHO                     
   AND OPL.UNIDADEDOCORIGEM = E.UNIDADEORCAMENTARIA         
 WHERE E.ENTIDADE         = :entidade                       
   AND ((E.CONTRAPARTIDA  = 'N')                          
    OR  (E.CONTRAPARTIDA  IS NULL))                         
   AND OP.ESTORNO         = 'N'                           
   AND ((OP.IDCONTACORRENTE = :idContaCorrente              
   AND   B.MODELOPLANO      >= 8)                           
    OR  (CCB.REDUZIDO       = :local                        
   AND   NOT B.MODELOPLANO  < 8))                           
 GROUP BY OP.DATA                                           
 UNION ALL                                                  
SELECT RL.DATACONTABILIZADO AS DATA, SUM(RL.VALOR) AS VALOR 
  FROM ${db.contabilidade.schema}.ORDEMPAGAMENTO_LIQUIDACAO OPL
  LEFT OUTER JOIN ${db.contabilidade.schema}.PAGAMENTO OP
    ON OPL.ENTIDADE  = OP.ENTIDADE                          
   AND OPL.EXERCICIO = OP.ANOORDEMPAGAMENTO                 
   AND OPL.NOORDEM   = OP.NOORDEMPAGAMENTO                  
  LEFT OUTER JOIN ${db.contabilidade.schema}.EXERCICIO B
    ON OP.ENTIDADE  = B.ENTIDADE                            
   AND OP.EXERCICIO = B.EXERCICIO                           
  LEFT OUTER JOIN ${db.contabilidade.schema}.CONTABILCONTABANCO CCB
    ON OP.ENTIDADE    = CCB.ENTIDADE                        
   AND OP.EXERCICIO   = CCB.EXERCICIO                       
   AND OP.CONTADEBITO = CCB.CONTACONTABIL                   
  LEFT OUTER JOIN ${db.contabilidade.schema}.EMPENHO E
    ON OPL.ENTIDADE         = E.ENTIDADE                    
   AND OPL.ANODOCORIGEM     = E.EXERCICIO                   
   AND OPL.NODOCORIGEM      = E.EMPENHO                     
   AND OPL.UNIDADEDOCORIGEM = E.UNIDADEORCAMENTARIA         
  JOIN ${db.contabilidade.schema}.RETENCOESLIQUIDACAO RL
    ON RL.ENTIDADE         = OPL.ENTIDADE                   
   AND RL.EXERCICIO        = OPL.EXERCICIOLIQ               
   AND RL.TIPODOCORIGEM    = OPL.TIPODOCORIGEM              
   AND RL.ANODOCORIGEM     = OPL.ANODOCORIGEM               
   AND RL.NODOCORIGEM      = OPL.NODOCORIGEM                
   AND RL.UNIDADEDOCORIGEM = OPL.UNIDADEDOCORIGEM           
   AND RL.NOLIQUIDACAO     = OPL.NOLIQUIDACAO               
 WHERE E.ENTIDADE         = :entidade                       
   AND ((E.CONTRAPARTIDA  = 'N')                          
    OR  (E.CONTRAPARTIDA  IS NULL))                         
   AND OP.ESTORNO         = 'N'                           
   AND ((OP.IDCONTACORRENTE = :idContaCorrente              
   AND   B.MODELOPLANO      >= 8)                           
    OR  (CCB.REDUZIDO       = :local                        
   AND   NOT B.MODELOPLANO  < 8))                           
 GROUP BY RL.DATACONTABILIZADO                              
 ) PAGAMENTOS                                               
 GROUP BY DATA                                              
 ORDER BY DATA
